==> report_frontend-0.1.7.gem: app/controllers/report_frontend/logins_controller.rb <==
require_dependency "report_frontend/application_controller"

require 'uri'
require 'net/http'

module ReportFrontend
    class LoginsController < ApplicationController

        skip_before_action :verify_authenticity_token

        def index
        end

        def login
            parsed_params = login_params

            session[:token_server_url]  = parsed_params[:token_server_url].blank? ? Rails.application.config.default_token_server : parsed_params[:token_server_url]
            session[:login]             = parsed_params[:login]
            session[:password]          = parsed_params[:password]

            # No token provided? We will request one
            begin
                if parsed_params[:token].present?
                    # There is no token. Therefore we request one
                    url = URI(session[:token_server_url])

                    http = Net::HTTP.new(url.host, url.port)
                    http.use_ssl = url.scheme == 'https'
                    http.verify_mode = Rails.application.config.web_frontend[:HTTP_VERIFY_MODE]

                    request = Net::HTTP::Get.new(url)
                    basic = ActionController::HttpAuthentication::Basic
                    credentials = basic.encode_credentials(session[:login] , session[:password])

                    request["Authorization"] = credentials
                    request["cache-control"] = 'no-cache'

                    response = http.request(request)

                    if response.code_type == Net::HTTPOK
                        ::ReportFrontend::TokenManager.set_token(JSON.parse(response.read_body)["jwt"])
                        flash[:success] = "Token request successful!"
                    else
                        flash[:error] = "Unable to get token. Error: #{response.status}"
                    end
                else
                    ::ReportFrontend::TokenManager.set_token(parsed_params[:token])
                end
            rescue Exception => e
                flash[:error] = "Unable to request Token."
                Rails.logger.error "#{e}"
            end

            redirect_to "/"
        end

        def clear
            session.clear

            flash[:success] = "The stored token is removed!"

            redirect_to "/"
        end

        private
        def login_params
            params.permit(:token_server_url, :login, :password, :token)
        end
    end
end

==> report_frontend-0.1.9.gem: app/controllers/report_frontend/logins_controller.rb <==
require_dependency "report_frontend/application_controller"

require 'uri'
require 'net/http'

module ReportFrontend
    class LoginsController < ApplicationController

        skip_before_action :verify_authenticity_token

        def index
        end

        def login
            parsed_params = login_params

            session[:token_server_url]  = parsed_params[:token_server_url].blank? ? Rails.application.config.default_token_server : parsed_params[:token_server_url]
            session[:login]             = parsed_params[:login]
            session[:password]          = parsed_params[:password]

            # No token provided? We will request one
            begin
                unless parsed_params[:token].present?
                    # There is no token. Therefore we request one
                    url = URI(session[:token_server_url])

                    http = Net::HTTP.new(url.host, url.port)
                    http.use_ssl = url.scheme == 'https'
                    http.verify_mode = Rails.application.config.web_frontend[:HTTP_VERIFY_MODE]

                    request = Net::HTTP::Get.new(url)
                    basic = ActionController::HttpAuthentication::Basic
                    credentials = basic.encode_credentials(session[:login] , session[:password])

                    request["Authorization"] = credentials
                    request["cache-control"] = 'no-cache'

                    response = http.request(request)

                    if response.code_type == Net::HTTPOK
                        ::ReportFrontend::TokenManager.set_token(JSON.parse(response.read_body)["jwt"])
                        flash[:success] = "Token request successful!"
                    else
                        flash[:error] = "Unable to get token. Error: #{response.status}"
                    end
                else
                    ::ReportFrontend::TokenManager.set_token(parsed_params[:token])
                end
            rescue Exception => e
                flash[:error] = "Unable to request Token."
                Rails.logger.error "#{e}"
            end

            redirect_to "/"
        end

        def clear
            session.clear

            flash[:success] = "The stored token is removed!"

            redirect_to "/"
        end

        private
        def login_params
            params.permit(:token_server_url, :login, :password, :token)
        end
    end
end
